@@ -2,11 +2,10 @@
 // SPDX-License-Identifier: GPL-3.0-only
 
 #include "accountmodel.h"
-#include "account/abstractaccount.h"
-#include "account/relationship.h"
+
+#include "relationship.h"
+
 #include <KLocalizedString>
-#include <QCoreApplication>
-#include <QUrlQuery>
 
 AccountModel::AccountModel(QObject *parent)
     : TimelineModel(parent)
@@ -15,11 +14,7 @@ AccountModel::AccountModel(QObject *parent)
 
     connect(this, &AccountModel::identityChanged, this, &TimelineModel::nameChanged);
     connect(this, &AccountModel::filtersChanged, this, [this] {
-        beginResetModel();
-        qDeleteAll(m_timeline);
-        m_timeline.clear();
-        endResetModel();
-
+        reset();
         fillTimeline();
     });
     connect(this, &AccountModel::tabChanged, this, &AccountModel::updateTabFilters);
@@ -127,10 +122,7 @@ void AccountModel::fillTimeline(const QString &fromId)
         // if we just restarted the fetch (fromId is null) then we must clear the previous array
         // this can happen if we just entered the profile page (okay, just a no-op) or if the filters change
         if (fromId.isNull()) {
-            beginResetModel();
-            qDeleteAll(m_timeline);
-            m_timeline.clear();
-            endResetModel();
+            reset();
         }
 
         fetchedTimeline(reply->readAll(), true);
@@ -242,3 +234,13 @@ void AccountModel::updateTabFilters()
     }
     Q_EMIT filtersChanged();
 }
+
+void AccountModel::reset()
+{
+    beginResetModel();
+    qDeleteAll(m_timeline);
+    m_timeline.clear();
+    endResetModel();
+}
+
+#include "moc_accountmodel.cpp"
\ No newline at end of file
