@@ -3,11 +3,8 @@
 // SPDX-License-Identifier: GPL-3.0-only
 
 #include "threadmodel.h"
-#include "account/abstractaccount.h"
-#include "timelinemodel.h"
+
 #include <KLocalizedString>
-#include <QJsonObject>
-#include <qstringliteral.h>
 
 using namespace Qt::Literals::StringLiterals;
 
@@ -135,3 +132,13 @@ int ThreadModel::getRootIndex() const
 
     return -1;
 }
+
+void ThreadModel::reset()
+{
+    beginResetModel();
+    qDeleteAll(m_timeline);
+    m_timeline.clear();
+    endResetModel();
+}
+
+#include "moc_threadmodel.cpp"
\ No newline at end of file
