@@ -2,12 +2,14 @@
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include "filehelper.h"
+
+#include "abstractaccount.h"
 #include "filetransferjob.h"
+
 #ifdef HAVE_KIO
 #include <KIO/Job>
 #include <KJobTrackerInterface>
 #endif
-#include "account/abstractaccount.h"
 
 FileHelper::FileHelper(QObject *parent)
     : QObject(parent)
@@ -34,3 +36,11 @@ QString FileHelper::fileName(const QUrl &url) const
 {
     return url.fileName();
 }
+
+void FileHelper::forceRefreshTextDocument(QQuickTextDocument *textDocument, QQuickItem *item)
+{
+    // HACK: Workaround bug QTBUG 93281
+    connect(textDocument->textDocument(), SIGNAL(imagesLoaded()), item, SLOT(updateWholeDocument()));
+}
+
+#include "moc_filehelper.cpp"
\ No newline at end of file
